setClass(Class="citizenair_stations",
         representation=representation(phenomena = "data.frame", 
                                       stations = "data.frame"))
setClass(Class="citizenair_userdata",
         representation=representation(filename = "character", 
                                       file = "character", 
                                       time = "POSIXct", 
                                       content = "list", 
                                       phenomena = "character"))

#' @title Object of class CitizenAir
#' @description Object of class CitizenAir
#' @slot stations Object of class \code{citizenair_stations} as returned by \code{\link{read_stations}}
#' @slot citizen_data Object of class \code{citizenair_userdata} as returned by \code{\link{read_citizenair}}
#' @name CitizenAir-class
#' @rdname CitizenAir-class
#' @param endpoint An object of class Endpoint as returned by \code{as.Endpoint} 
#' @export 
#' @examples
#' library(sensorweb4R)
#' e <- as.Endpoint("http://geo.irceline.be/sos/api/v1")
#' ca <- new("CitizenAir", endpoint=e)
#' ca
setClass(Class = "CitizenAir",
         representation = representation(stations = "citizenair_stations", 
                                       citizen_data = "citizenair_userdata"))
setMethod(f = "initialize", 
          signature = "CitizenAir",
          definition = function(.Object, endpoint) {            
            .Object@stations <- read_stations(endpoint)
            .Object@citizen_data <- citizenair_userdata_empty()
            .Object
          })


#' @title TODO
#' @description TODO
#' @param object the object
#' @export
as_sp <- function(object){
  if(inherits(object, "citizenair_stations")){
    x <- as.data.frame(object$stations)
    x <- sp::SpatialPointsDataFrame(coords = x[, c("lon", "lat")], 
                                    data = x, proj4string = CRS("+proj=longlat +datum=WGS84 +ellps=WGS84 +towgs84=0,0,0"))  
  }else{
    stop("not implemented")
  }
  x
}



